{*****************************************************************************
*                                                                            *
*  FGIW2.PAS                                                                 *
*                                                                            *
*  This example shows how to play a flic file from an FGI library, using     *
*  either fgi_showflic() or the low-level fgi_flicxxx() routines.            *
*                                                                            *
*****************************************************************************}

program FGIW2;

uses WinTypes, WinProcs, FGWin, FGIWin;

const
  AppName = 'FGIW2';

var
  cxClient, cyClient : word;
  dc   : hDC;
  hpal : hPalette;
  hvb  : integer;
  hfgi : integer;
  context : array [1..20] of byte;

{*****************************************************************************
*                                                                            *
*  WindowProc                                                                *
*                                                                            *
*  Window procedure to handle messages sent to the window.                   *
*                                                                            *
*****************************************************************************}

function WindowProc(window : hwnd; message : word;
                    wParam : word; lParam : longint): longint; export;
var
  ps : tPaintStruct;

begin

  WindowProc := 0;

  case message of

    WM_CREATE:
    begin
      dc := GetDC(window);
      fg_setdc(dc);
      hpal := fg_defpal;
      fg_realize(hpal);

      fg_vbinit;
      hvb := fg_vballoc(320,200);
      fg_vbopen(hvb);
      fg_vbcolors;

      hfgi := fgi_open('EXAMPLE.FGI'+chr(0));
      if hfgi = 0 then
      begin
        MessageBox(window,'Unable to open FGI file.','Error',MB_ICONSTOP or MB_OK);
        DestroyWindow(window);
        Exit;
      end;
      fgi_flicopen('GLASS.FLI'+chr(0),context,hfgi);
      fg_flicplay(context,1,0);
      Exit;
    end;

    WM_KEYDOWN:
      case wParam of

        VK_F1:
        begin
          fgi_showflic('GLASS.FLI'+chr(0),2,0,hfgi);
        end;

        VK_F2:
        begin
          fgi_flicskip(context,-1);
          while fg_flicplay(context,1,0) > 0 do
            fg_vbscale(0,fg_getmaxx,0,fg_getmaxy,0,cxClient-1,0,cyClient-1);
          fgi_flicskip(context,-1);
          while fg_flicplay(context,1,0) > 0 do
            fg_vbscale(0,fg_getmaxx,0,fg_getmaxy,0,cxClient-1,0,cyClient-1);
        end;

      end;

    WM_PAINT:
    begin
      BeginPaint(window,ps);
      fg_vbscale(0,fg_getmaxx,0,fg_getmaxy,0,cxClient-1,0,cyClient-1);
      EndPaint(window,ps);
      Exit;
    end;

    WM_SETFOCUS:
    begin
      fg_realize(hpal);
      InvalidateRect(window,nil,TRUE);
      Exit;
    end;

    WM_SIZE:
    begin
      cxClient := LOWORD(lParam);
      cyClient := HIWORD(lParam);
      Exit;
    end;

    WM_DESTROY:
    begin
      fgi_close(hfgi);
      fg_vbclose;
      fg_vbfree(hvb);
      fg_vbfin;
      DeleteObject(hpal);
      ReleaseDC(window,dc);
      PostQuitMessage(0);
      Exit;
    end;

  end;
  WindowProc := DefWindowProc(window,message,wParam,lParam);
end;

{****************************************************************************}

procedure WinMain;

var
  window      : hWnd;
  message     : tMsg;
  WindowClass : tWndClass;

begin
  if hPrevInst = 0 then
  begin
    WindowClass.style         := CS_HREDRAW OR CS_VREDRAW OR CS_OWNDC;
    WindowClass.lpfnWndProc   := @WindowProc;
    WindowClass.cbClsExtra    := 0;
    WindowClass.cbWndExtra    := 0;
    WindowClass.hInstance     := hInstance;
    WindowClass.hIcon         := LoadIcon(0,IDI_APPLICATION);
    WindowClass.hCursor       := LoadCursor(0,IDC_ARROW);
    WindowClass.hbrBackground := 0;
    WindowClass.lpszMenuName  := nil;
    WindowClass.lpszClassName := AppName;
    if not RegisterClass(WindowClass) then Halt(255);
  end;

  window := CreateWindow(
    AppName,                  { window class name }
    'Example FGIW2',          { window caption }
    WS_OVERLAPPEDWINDOW,      { window style }
    CW_USEDEFAULT,            { initial x position }
    CW_USEDEFAULT,            { initial y position }
    CW_USEDEFAULT,            { initial x size }
    CW_USEDEFAULT,            { initial y size }
    0,                        { parent window handle }
    0,                        { window menu handle }
    hInstance,                { program instance handle }
    nil);                     { creation parameters }

  ShowWindow(window,CmdShow);
  UpdateWindow(window);

  while GetMessage(message,0,0,0) do
  begin
    TranslateMessage(message);
    DispatchMessage(message);
  end;

  Halt(message.wParam);
end;

begin
  WinMain;
end.
